import { FunctionComponent } from 'react';
import { Immutable } from '@simplux/core';
import { ReactNode } from 'react';
import { SimpluxModule } from '@simplux/core';
import { SimpluxSelector } from '@simplux/core';

/**
 * A provider for allowing components to use state from simplux modules.
 *
 * It is recommended to wrap your entire application with a single provider.
 *
 * @public
 */
export declare const SimpluxProvider: FunctionComponent<{
    children: ReactNode;
}>;

/**
 * A react hook that allows accessing a module's state inside
 * a component. Whenever the state of the module changes the
 * component using the hook will be re-rendered.
 *
 * @param simpluxModule - the module to return the state for
 *
 * @returns the state of the module
 *
 * @public
 */
export declare function useSimplux<TState>(simpluxModule: SimpluxModule<TState>): Immutable<TState>;

/**
 * A react hook that allows accessing a module's state inside
 * a component. Whenever the result of the selector changes the
 * component using the hook will be re-rendered.
 *
 * @param selector - the module selector that determines the slice
 * of the module's state which is returned
 * @param args - the arguments for the selector
 *
 * @returns the result of the selector
 *
 * @public
 */
export declare function useSimplux<TState, TArgs extends any[], TResult>(selector: SimpluxSelector<TState, TArgs, TResult>, ...args: TArgs): TResult;

export { }
